@@ -3,6 +3,13 @@ from django.core.exceptions import ImproperlyConfigured
 from django.http import Http404
 from django_arecibo.wrapper import post
 
+has_celery = True
+try:
+    from django_arecibo.tasks import post as delayed_post
+except ImportError, e:
+    has_celery = False
+
+
 def arecibo_post(method, request, exception):
     if getattr(settings, 'ARECIBO_SERVER_URL', ''):
         if isinstance(exception, Http404):
@@ -18,19 +25,9 @@ class AreciboMiddleware(object):
 class AreciboMiddlewareCelery(object):
 
     def __init__(self):
-        '''
-        Unlike the process_* methods which get called once per request,
-        __init__ gets called only once, when the Web server starts up.
-        
-        (https://docs.djangoproject.com/en/dev/topics/http/middleware/#s-init)
-        '''
-        try:
-            from django_arecibo.tasks import post as delayed_post
-        except ImportError, e:
-            if str(e) == 'No module named celery.decorators':
-                raise ImproperlyConfigured('Cannot use AreciboMiddlewareCelery\
-                    if Celery is not installed.')
-            raise e
+        if not has_celery:
+            raise ImproperlyConfigured('Cannot use AreciboMiddlewareCelery '
+                                       'if Celery is not installed.')
 
     def process_exception(self, request, exception):
         return arecibo_post(delayed_post, request, exception)
